@@ -13,7 +13,7 @@ from compose_companion.functions import (
     container_start,
     container_pause,
     container_up,
-    print_config
+    print_config,
 )
 
 
@@ -253,9 +253,7 @@ def ps(
     if not targets:
         run(f"docker compose -f {compose_file} ps")
         return
-    run(
-        f"docker compose -f {compose_file} ps {' '.join(targets)} -a={include_stopped}"
-    )
+    run(f"docker compose -f {compose_file} ps {' '.join(targets)} -a={include_stopped}")
 
 
 @app.command()
@@ -275,17 +273,15 @@ def config(
     conf = Configurations()
 
     if key and key in conf.config_keys:
-        if (key == 'compose_file' and value):
+        if key == "compose_file" and value:
             conf.compose_file = value
-        elif (key == 'companion_file' and value):
+        elif key == "companion_file" and value:
             conf.companion_file = value
         print(conf.get_config(key))
         return
 
     if key and key not in conf.config_keys:
-        err_console.print(
-            "Invalid Key. Here are the available keys:\n"
-        )
+        err_console.print("Invalid Key. Here are the available keys:\n")
 
     print_config()
 
